@@ -1,8 +1,8 @@
 
 /*
- *  Time-stamp:      "2003-05-26 08:04:30 bkorb"
+ *  Time-stamp:      "2004-01-01 09:10:28 bkorb"
  *
- *  autoopts.h  $Id: autoopts.h,v 2.38 2003/05/31 22:59:15 bkorb Exp $
+ *  autoopts.h  $Id: autoopts.h,v 2.44 2004/01/01 20:06:00 bkorb Exp $
  *
  *  This file defines all the global structures and special values
  *  used in the automated option processing library.
@@ -66,6 +66,12 @@
 #include "options.h"
 #include "streqv.h"
 
+#define AO_NAME_LIMIT    127
+#define AO_NAME_SIZE     (AO_NAME_LIMIT + 1)
+#ifndef MAXPATHLEN
+#  define MAXPATHLEN     4096
+#endif
+
 /*
  *  Convert the number to a list usable in a printf call
  */
@@ -76,6 +82,12 @@
 
 #define SKIP_OPT(p)  (((p)->fOptState & (OPTST_DOCUMENT|OPTST_OMITTED)) != 0)
 
+typedef int tDirection;
+#define DIRECTION_PRESET  -1
+#define DIRECTION_PROCESS  1
+#define PROCESSING(d)     ((d)>0)
+#define PRESETTING(d)     ((d)<0)
+
 /*
  *  Procedure success codes
  *
@@ -127,8 +139,36 @@ typedef struct {
     tUL        flags;
     teOptType  optType;
     int        argType;
-    char*      pzOptArg;
+    tCC*       pzOptArg;
 } tOptState;
+#define OPTSTATE_INITIALIZER \
+    { NULL, OPTST_DEFINED, TOPT_UNDEFINED, 0, NULL }
+
+#define TEXTTO_TABLE \
+        _TT_( LONGUSAGE ) \
+        _TT_( USAGE ) \
+        _TT_( VERSION )
+#define _TT_(n) \
+        TT_ ## n ,
+
+typedef enum { TEXTTO_TABLE COUNT_TT } teTextTo;
+
+#undef _TT_
+
+typedef struct {
+    tCC*    pzStr;
+    tCC*    pzReq;
+    tCC*    pzNum;
+    tCC*    pzKey;
+    tCC*    pzKeyL;
+    tCC*    pzBool;
+    tCC*    pzOpt;
+    tCC*    pzNo;
+    tCC*    pzBrk;
+    tCC*    pzNoF;
+    tCC*    pzSpc;
+    tCC*    pzOptFmt;
+} arg_types_t;
 
 #  define AGALOC( c, w )        malloc( c )
 #  define AGREALOC( p, c, w )   realloc( p, c )
@@ -138,39 +178,52 @@ typedef struct {
 
 #ifdef AUTOGEN_BUILD
 #  include <snprintfv/printf.h>
+#endif /* AUTOGEN_BUILD */
+
+/*
+ *  Define and initialize all the user visible strings.
+ *  We do not do translations.  If translations are to be done, then
+ *  the client will provide a callback for that purpose.
+ */
+#undef DO_TRANSLATIONS
+#include "usage-txt.h"
 
 /*
  *  File pointer for usage output
  */
 extern FILE* option_usage_fp;
 
-/*
- *  optionUsage print the usage text for the program described by the
- *  option descriptor.  Does not return.  Calls ``exit(3)'' with exitCode.
- */
-extern void optionUsage( tOptions*, int exitCode );
-
-/*
- *  optionSave saves the option state into an RC or INI file in
- *  the *LAST* defined directory in the papzHomeList.
- */
-extern void optionSave( tOptions* pOpts );
-
-/*
- *  optionMakePath  --  translate and construct a path
- *
- *  This routine does environment variable expansion if the first character
- *  is a ``$''.  If it starts with two dollar characters, then the path
- *  is relative to the location of the executable.
- */
-extern ag_bool optionMakePath(
-    char*    pzBuf,
-    size_t   bufSize,
-    tCC*     pzName,
-    tCC*     pzProgPath );
-
 extern tOptProc doVersion, doPagedUsage, doLoadOpt;
 
+#define LOCAL static
+#ifdef AUTOOPTS_INTERNAL
+/* === LOCAL PROCEDURES === */
+
+/* autoopts.c */
+static tSuccess
+handleOption( tOptions* pOpts, tOptState* pOptState );
+
+static tSuccess
+longOptionFind( tOptions* pOpts, char* pzOptName, tOptState* pOptState );
+
+static tSuccess
+shortOptionFind( tOptions* pOpts, tUC optValue, tOptState* pOptState );
+
+
+/* load.c */
+static void
+filePreset(
+    tOptions*     pOpts,
+    const char*   pzFileName,
+    int           direction );
+
+
+/* sort.c */
+static void
+optionSort( tOptions* pOpts );
+
+/* === END LOCALS === */
+#endif /* GUILE_OPTIONS */
 #endif /* AUTOGEN_AUTOOPTS_H */
 /*
  * Local Variables:
