@@ -1,6 +1,6 @@
 
 /*
- *  $Id: numeric.c,v 2.10 2003/04/21 03:27:50 bkorb Exp $
+ *  $Id: numeric.c,v 2.13 2004/01/01 20:06:00 bkorb Exp $
  *
  *   Automated Options Paged Usage module.
  *
@@ -51,13 +51,21 @@
  * If you do not wish that, delete this exception notice.
  */
 
-/*
- *  The value is true, unless it starts with 'n' or 'f' or "#f" or
- *  it is an empty string or it is a number that evaluates to zero
- */
-void optionNumericVal( pOpts, pOD )
-    tOptions* pOpts;
-    tOptDesc* pOD;
+/* === STATIC PROCS === */
+/* === END STATIC PROCS === */
+
+/*=export_func  optionNumericVal
+ * private:
+ *
+ * what:  Decipher a boolean value
+ * arg:   + tOptions* + pOpts    + program options descriptor +
+ * arg:   + tOptDesc* + pOptDesc + the descriptor for this arg +
+ *
+ * doc:
+ *  Decipher a numeric value.
+=*/
+void
+optionNumericVal( tOptions* pOpts, tOptDesc* pOD )
 {
     char* pz;
     long  val;
@@ -72,8 +80,7 @@ void optionNumericVal( pOpts, pOD )
 
     val = strtol( pOD->pzLastArg, &pz, 0 );
     if (*pz != NUL) {
-        fprintf( stderr, "%s error:  `%s' is not a recognizable number\n",
-                 pOpts->pzProgName, pOD->pzLastArg );
+        fprintf( stderr, zNotNumber, pOpts->pzProgName, pOD->pzLastArg );
         (*(pOpts->pUsageProc))(pOpts, EXIT_FAILURE);
     }
 
